@@ -540,7 +540,7 @@ class GitlabContainerRunner(
         *,
         gitlabtoken: builtins.str,
         block_duration: typing.Optional[BlockDuration] = None,
-        docker_volumes: typing.Optional[typing.Sequence[DockerVolumes]] = None,
+        docker_volumes: typing.Optional[typing.Sequence[typing.Union[DockerVolumes, typing.Dict[str, typing.Any]]]] = None,
         ebs_size: typing.Optional[jsii.Number] = None,
         ec2iamrole: typing.Optional[aws_cdk.aws_iam.IRole] = None,
         ec2type: typing.Optional[builtins.str] = None,
@@ -555,7 +555,7 @@ class GitlabContainerRunner(
         tag3: typing.Optional[builtins.str] = None,
         tags: typing.Optional[typing.Sequence[builtins.str]] = None,
         valid_until: typing.Optional[builtins.str] = None,
-        vpc_subnet: typing.Optional[aws_cdk.aws_ec2.SubnetSelection] = None,
+        vpc_subnet: typing.Optional[typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''
         :param scope: -
@@ -611,7 +611,7 @@ class GitlabContainerRunner(
     @jsii.member(jsii_name="createUserData")
     def create_user_data(
         self,
-        props: "GitlabContainerRunnerProps",
+        props: typing.Union["GitlabContainerRunnerProps", typing.Dict[str, typing.Any]],
         bucket_name: builtins.str,
     ) -> typing.List[builtins.str]:
         '''
@@ -726,7 +726,7 @@ class GitlabContainerRunnerProps:
         *,
         gitlabtoken: builtins.str,
         block_duration: typing.Optional[BlockDuration] = None,
-        docker_volumes: typing.Optional[typing.Sequence[DockerVolumes]] = None,
+        docker_volumes: typing.Optional[typing.Sequence[typing.Union[DockerVolumes, typing.Dict[str, typing.Any]]]] = None,
         ebs_size: typing.Optional[jsii.Number] = None,
         ec2iamrole: typing.Optional[aws_cdk.aws_iam.IRole] = None,
         ec2type: typing.Optional[builtins.str] = None,
@@ -741,7 +741,7 @@ class GitlabContainerRunnerProps:
         tag3: typing.Optional[builtins.str] = None,
         tags: typing.Optional[typing.Sequence[builtins.str]] = None,
         valid_until: typing.Optional[builtins.str] = None,
-        vpc_subnet: typing.Optional[aws_cdk.aws_ec2.SubnetSelection] = None,
+        vpc_subnet: typing.Optional[typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''(experimental) GitlabContainerRunner Props.
 
@@ -1152,7 +1152,7 @@ class GitlabRunnerAutoscaling(
         gitlab_token: builtins.str,
         alarms: typing.Optional[typing.Sequence[typing.Mapping[typing.Any, typing.Any]]] = None,
         desired_capacity: typing.Optional[jsii.Number] = None,
-        docker_volumes: typing.Optional[typing.Sequence[DockerVolumes]] = None,
+        docker_volumes: typing.Optional[typing.Sequence[typing.Union[DockerVolumes, typing.Dict[str, typing.Any]]]] = None,
         ebs_size: typing.Optional[jsii.Number] = None,
         gitlab_runner_image: typing.Optional[builtins.str] = None,
         gitlab_url: typing.Optional[builtins.str] = None,
@@ -1163,7 +1163,7 @@ class GitlabRunnerAutoscaling(
         spot_instance: typing.Optional[builtins.bool] = None,
         tags: typing.Optional[typing.Sequence[builtins.str]] = None,
         vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
-        vpc_subnet: typing.Optional[aws_cdk.aws_ec2.SubnetSelection] = None,
+        vpc_subnet: typing.Optional[typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''
         :param scope: -
@@ -1217,7 +1217,7 @@ class GitlabRunnerAutoscaling(
         gitlab_token: builtins.str,
         alarms: typing.Optional[typing.Sequence[typing.Mapping[typing.Any, typing.Any]]] = None,
         desired_capacity: typing.Optional[jsii.Number] = None,
-        docker_volumes: typing.Optional[typing.Sequence[DockerVolumes]] = None,
+        docker_volumes: typing.Optional[typing.Sequence[typing.Union[DockerVolumes, typing.Dict[str, typing.Any]]]] = None,
         ebs_size: typing.Optional[jsii.Number] = None,
         gitlab_runner_image: typing.Optional[builtins.str] = None,
         gitlab_url: typing.Optional[builtins.str] = None,
@@ -1228,7 +1228,7 @@ class GitlabRunnerAutoscaling(
         spot_instance: typing.Optional[builtins.bool] = None,
         tags: typing.Optional[typing.Sequence[builtins.str]] = None,
         vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
-        vpc_subnet: typing.Optional[aws_cdk.aws_ec2.SubnetSelection] = None,
+        vpc_subnet: typing.Optional[typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]]] = None,
     ) -> typing.List[builtins.str]:
         '''
         :param gitlab_token: (experimental) Gitlab token.
@@ -1345,7 +1345,7 @@ class GitlabRunnerAutoscalingProps:
         gitlab_token: builtins.str,
         alarms: typing.Optional[typing.Sequence[typing.Mapping[typing.Any, typing.Any]]] = None,
         desired_capacity: typing.Optional[jsii.Number] = None,
-        docker_volumes: typing.Optional[typing.Sequence[DockerVolumes]] = None,
+        docker_volumes: typing.Optional[typing.Sequence[typing.Union[DockerVolumes, typing.Dict[str, typing.Any]]]] = None,
         ebs_size: typing.Optional[jsii.Number] = None,
         gitlab_runner_image: typing.Optional[builtins.str] = None,
         gitlab_url: typing.Optional[builtins.str] = None,
@@ -1356,7 +1356,7 @@ class GitlabRunnerAutoscalingProps:
         spot_instance: typing.Optional[builtins.bool] = None,
         tags: typing.Optional[typing.Sequence[builtins.str]] = None,
         vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
-        vpc_subnet: typing.Optional[aws_cdk.aws_ec2.SubnetSelection] = None,
+        vpc_subnet: typing.Optional[typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''(experimental) GitlabRunnerAutoscaling Props.
 
